Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/FastLED/FastLED.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Garcia <danielgarcia@gmail.com>2016-06-04 09:13:15 +0300
committerDaniel Garcia <danielgarcia@gmail.com>2016-06-04 09:13:15 +0300
commit66ae6702aa4bc570cfae8513d873dfb6040af978 (patch)
tree64694077fcafc514081441627be4025426fcbf45
parent96704eefab0e3660ab0fb009b0b84c5336ae65fb (diff)
Thought I made the APA102 default to 12Mhz already - closes #314
-rw-r--r--chipsets.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chipsets.h b/chipsets.h
index 0bcac3c7..5783149f 100644
--- a/chipsets.h
+++ b/chipsets.h
@@ -153,8 +153,8 @@ class WS2803Controller : public WS2801Controller<DATA_PIN, CLOCK_PIN, RGB_ORDER,
/// @tparam DATA_PIN the data pin for these leds
/// @tparam CLOCK_PIN the clock pin for these leds
/// @tparam RGB_ORDER the RGB ordering for these leds
-/// @tparam SPI_SPEED the clock divider used for these leds. Set using the DATA_RATE_MHZ/DATA_RATE_KHZ macros. Defaults to DATA_RATE_MHZ(24)
-template <uint8_t DATA_PIN, uint8_t CLOCK_PIN, EOrder RGB_ORDER = RGB, uint8_t SPI_SPEED = DATA_RATE_MHZ(24)>
+/// @tparam SPI_SPEED the clock divider used for these leds. Set using the DATA_RATE_MHZ/DATA_RATE_KHZ macros. Defaults to DATA_RATE_MHZ(12)
+template <uint8_t DATA_PIN, uint8_t CLOCK_PIN, EOrder RGB_ORDER = RGB, uint8_t SPI_SPEED = DATA_RATE_MHZ(12)>
class APA102Controller : public CPixelLEDController<RGB_ORDER> {
typedef SPIOutput<DATA_PIN, CLOCK_PIN, SPI_SPEED> SPI;
SPI mSPI;